//
// FILE: OptiTest.java
//
//import ...;
import ewe.sys.Vm;
/**
 Interface for Classes which compare optimised ode with nonoptimised one. <br>

 <br>

 <br>
 <b>Started:</b>     <DD>07.04.2007</DD><br>
 <b>LastModified:</b><DD>26.07.2007</DD><br>

<br><b><u>Design-Decisions:</u></b>
<ul>
 <li></li>
</ul>

<font size=-1>
<br><b><u>HISTORY</u></b>
<ul><b>08.04.2007</b>
 <li>defined the methods of this Interface and documented them.</li>
<br><b>dd.mm.yyyy</b>
 <li></li>
</ul>
</font>

<br><b><u>TODO:</u></b>
<ul>
 <li></li>
</ul>

<br><b><u>IDEAS FOR FURTHER EXTENSIONS:</u></b>
<ul>
 <li></li>
</ul>
<table border width=100%>
 <tr><td width=99%><b>threadsafe</b></td>               <th></th></tr>
 <tr><td>optimised for <b>memory economicality</b></td> <th></th></tr>
 <tr><td>optimised for <b>speed</b></td>                <th></th></tr>
 <tr><td><b>EWE-usable</b></td>                         <th></th></tr>
 <tr><td><b>Tested with JUnit-tests</b></td>            <th><font size=-2>(dd.mm.yyyy)</font></th></tr>
 <tr><td><b></b></td>                  <th><font color=green>YES</font></th></tr>
 <tr><td><b></b></td>                  <th><font color=red>NO</font></th></tr>
</table>
 @author Folke Rinneberg (Folke&#64;Rinneberg.de) <a href="http://www.Rinneberg.de/index.htm">Homepage</a>
*/
public interface OptiTest
{
 /**Returns a human readable String as name for this optimisation
  * (short sentence). <br>
  * @return human readable String as name of the optimisation
  */
  public String getTestname();

 /**finds number of internal runs which needs about a given number of seconds
  * for the unoptimised Version. <br>
  * This is stored internaly (in a static value )for later calls of
  * <code>runUnoptimisedVersion()</code> and
  * <code>runOptimisedVersion()</code>
  */
  public void findAndSetNumberOfRuns(final int milliSecondsUnoptimised);


 /**Runs the unoptimised Version. <br>
  * The intern test-loop should be run multible times to giv the VM the
  * chance of runtime-optimisation.<br>
  * The returned value should be the mesured time of atest-loop-run after
  * some previous, not medured runs.
  * @return number of milli-seconds needed
  */
  public int runUnoptimisedVersion();
 /**Runs the optimised Version. <br>
  * The intern test-loop should be run multible times to giv the VM the
  * chance of runtime-optimisation.<br>
  * The returned value should be the mesured time of atest-loop-run after
  * some previous, not medured runs.
  * @return number of milli-seconds needed
  */
  public int runOptimisedVersion();

 /**Runs optimised and unoptimised version in aloop with output to
  * <ode>System.err</code> or <code>System.out</code>. <br>
  * This method should als be called by the
  * <code>public&nbsp;static&nbsp;void&nbsp;main(String ags[])</code>-method.
  */
  public void runForEver();

}//end-interface
